summaryrefslogtreecommitdiffstats
path: root/chalk/sdk/kis_shared_ptr_vector.h
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/sdk/kis_shared_ptr_vector.h')
-rw-r--r--chalk/sdk/kis_shared_ptr_vector.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/chalk/sdk/kis_shared_ptr_vector.h b/chalk/sdk/kis_shared_ptr_vector.h
index ee7961ae..0e7c99e8 100644
--- a/chalk/sdk/kis_shared_ptr_vector.h
+++ b/chalk/sdk/kis_shared_ptr_vector.h
@@ -25,15 +25,15 @@
/**
* TQValueVector does not always destroy an element when it is erased.
* If the items it is holding are KSharedPtr, this can result in hidden
* references to objects that cannot be accounted for. This class
* sets the KSharedPtr to 0 on erase, which dereferences the object as
* expected.
*/
template <class T>
-class KisSharedPtrVector : public TQValueVector< KSharedPtr<T> >
+class KisSharedPtrVector : public TQValueVector< TDESharedPtr<T> >
{
- typedef TQValueVector< KSharedPtr<T> > super;
+ typedef TQValueVector< TDESharedPtr<T> > super;
public:
KisSharedPtrVector() {}
@@ -57,7 +57,7 @@ public:
return super::erase(first, last);
}
- bool contains(KSharedPtr<T> ptr) const
+ bool contains(TDESharedPtr<T> ptr) const
{
for (int i = 0, n = super::count(); i < n; ++i)
if (super::at(i) == ptr)
@@ -25,15 +25,15 @@
/**
* TQValueVector does not always destroy an element when it is erased.
- * If the items it is holding are KSharedPtr, this can result in hidden
+ * If the items it is holding are TDESharedPtr, this can result in hidden
* references to objects that cannot be accounted for. This class
@@ -25,15 +25,15 @@
* references to objects that cannot be accounted for. This class
- * sets the KSharedPtr to 0 on erase, which dereferences the object as
+ * sets the TDESharedPtr to 0 on erase, which dereferences the object as
* expected.
*/